summaryrefslogtreecommitdiffstats
path: root/ipapython/ipa_log_manager.py
diff options
context:
space:
mode:
Diffstat (limited to 'ipapython/ipa_log_manager.py')
-rw-r--r--ipapython/ipa_log_manager.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/ipapython/ipa_log_manager.py b/ipapython/ipa_log_manager.py
index 8af0f79a7..f2cd4d3a1 100644
--- a/ipapython/ipa_log_manager.py
+++ b/ipapython/ipa_log_manager.py
@@ -101,10 +101,10 @@ class IPALogManager(LogManager):
in the Env config must begin with "log_logger_level\_" and then be
followed by a symbolic or numeric log level, for example::
- log_logger_level_debug = ipalib\.dn\..*
+ log_logger_level_debug = ipapython\.dn\..*
log_logger_level_35 = ipalib\.plugins\.dogtag
The first line says any logger belonging to the ipalib.dn module
will have it's level configured to debug.
The second line say the ipa.plugins.dogtag logger will be
@@ -101,10 +101,10 @@ class IPALogManager(LogManager):
log_logger_level_35 = ipalib\.plugins\.dogtag
- The first line says any logger belonging to the ipalib.dn module
+ The first line says any logger belonging to the ipapython.dn module
will have it's level configured to debug.
The second line say the ipa.plugins.dogtag logger will be